# oneNeuron_pypi
oneNeuron_pypi

# Reference

[Official Python docs](https://packaging.python.org/tutorials/packaging-projects/)


# Reference
[git hub official docs](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)